@@ -304,10 +304,28 @@ DEFUN(_IO_file_underflow, (fp),
 		       fp->_IO_buf_end - fp->_IO_buf_base);
   if (count <= 0)
     {
+      /* 
+       * I think EAGAIN and EWOULDBLOCK should be treated as
+       * EOF. H.J.
+       */
+#ifdef EAGAIN
+#if defined(EWOULDBLOCK) && EWOULDBLOCK != EAGAIN
+      if (count == 0 || errno == EAGAIN
+	|| errno == EWOULDBLOCK)
+#else
+      if (count == 0 || errno == EAGAIN)
+#endif
+#else
+#ifdef EWOULDBLOCK
+      if (count == 0 || errno == EWOULDBLOCK)
+#else
       if (count == 0)
+#endif
+#endif
 	fp->_flags |= _IO_EOF_SEEN;
       else
-	fp->_flags |= _IO_ERR_SEEN, count = 0;
+	fp->_flags |= _IO_ERR_SEEN;
+      count = 0;
   }
   fp->_IO_read_end += count;
   if (count == 0)
