@@ -18,7 +18,11 @@ Cambridge, MA 02139, USA.  */
 
 #include <ansidecl.h>
 #include <errno.h>
-#include <math.h>
+#if defined(__i386__)
+#include <fpu_control.h>
+#include <signal.h>
+extern int __getfpucw(void);
+#endif /*  defined(__i386__) */
 
 /* Deal with an infinite or NaN result.
    If ERROR is ERANGE, result is +Inf;
@@ -27,6 +31,8 @@ Cambridge, MA 02139, USA.  */
    This will set `errno' to either ERANGE or EDOM,
    and may return an infinity or NaN, or may do something else.  */
 
+long double __infnanl( int );
+
 long double
 DEFUN(__infnanl, (error), int error)
 {
@@ -37,21 +43,35 @@ DEFUN(__infnanl, (error), int error)
 
    u.i[0] = 0;
    u.i[1] = 0;
-   u.i[2] = 0x7fff;
   switch (error)
     {
     case ERANGE:
       errno = ERANGE;
+#if defined(__i386__)
+      if (!(__getfpucw() & _FPU_MASK_OM))
+	(void) raise(SIGFPE);
+#endif /* defined(__i386__) */
+      u.i[2] = 0x7fff;
       return (u.d);
 
     case - ERANGE:
       errno = ERANGE;
-      u.i[2] |= 0x8000;
+#if defined(__i386__)
+      if (!(__getfpucw() & _FPU_MASK_OM))
+	(void) raise(SIGFPE);
+#endif /* defined(__i386__) */
+      u.i[2] = 0xffff;
       return (u.d);
 
     default:
       errno = EDOM;
-      u.i[1] = 0x80000000;
+#if defined(__i386__)
+      if (!(__getfpucw() & _FPU_MASK_IM))
+	(void) raise(SIGFPE);
+#endif /* defined(__i386__) */
+      u.i[2] = 0xffff;
+      u.i[1] = 0xC0000000;
       return (u.d);
     }
 }
+
