@@ -806,6 +806,13 @@ char *crypt(key, salt)
     ufc_long *s;
     char ktab[9];
 
+#ifndef NO_MD5_CRYPT
+    extern char *crypt_md5();
+
+    if (strncmp(salt, "$1$", 3) == 0)
+      return crypt_md5(key, salt);
+#endif
+
     /*
      * Hack DES tables according to salt
      */
