@@ -817,7 +817,7 @@ yp_maplist (char *indomain, struct ypmaplist **outmaplist)
   bzero ((char *) &ypml, sizeof ypml);
   
   result = clnt_call (ysd->dom_client, YPPROC_MAPLIST,
-                      (xdrproc_t)xdr_domainname, indomain,
+                      (xdrproc_t)xdr_domainname, &indomain,
                       (xdrproc_t)xdr_ypresp_maplist, (char *)&ypml,
                       tv);
   if (result != RPC_SUCCESS)
